@@ -54,10 +54,11 @@ InlineQueryResult = Union[
 class ApiBase:  # pylint: disable=too-few-public-methods
     """This class contains methods that are not methods Telegram Bot Api."""
 
-    def __init__(self, token: str, proxies: Optional[dict]):
+    def __init__(self, token: str, proxies: Optional[dict] = None):
         self.token = token
         self.proxies = proxies
 
+
     @staticmethod
     def _get_tg_api_method_name(py_style_method_name):
         """Get Telegram API method name from python method name."""
@@ -135,9 +136,15 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         token (str): token
     """
 
-    def __init__(self, token: str, proxies=Optional[dict]):
+    def __init__(self, token: str, proxies: Optional[dict] = None):
         super().__init__(token=token, proxies=proxies)
 
+    @property
+    def public_ip(self) -> str:
+        """Get public ip address."""
+        return requests.get('https://checkip.amazonaws.com',
+                            proxies=self.proxies).text.strip()
+
     def set_chat_photo(
             self,
             chat_id: Union[int, str],
